@@ -8,7 +8,7 @@
 # @Description : 包含基本的文件读写，指定扩展名文件查找等基本工具
 
 
-__version__ = "0.7.6"
+__version__ = "0.10.6"
 
 
 import json
@@ -19,6 +19,32 @@ from typing import List, Union
 from gitopenlib.utils import basics as gb
 
 
+def list_intersection(listA: list, listB: list):
+    """
+    求两个list的交集，listA中的哪些元素，在listB中出现了。
+    注意，listA和listB的顺序不一样，交集结果不一样。
+    """
+    return [it for it in listA if it in listB]
+
+
+def is_all_chinese(strs: str):
+    """
+    检验是否全是中文字符
+    """
+    for _char in strs:
+        if not "\u4e00" <= _char <= "\u9fa5":
+            return False
+    return True
+
+
+def is_contains_chinese(strs: str):
+    """检验是否含有中文字符"""
+    for _char in strs:
+        if "\u4e00" <= _char <= "\u9fa5":
+            return True
+    return False
+
+
 def dict_extremum(data: dict, type=0) -> tuple:
     """
     找到dict中value的极值，并返回key，若极值有多个，则返回多个key
